==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpneBinop.h <==
// public final class soot.jimple.parser.node.ACmpneBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 28fea7ff64ce6cdb soot_jimple_parser_node_ACmpneBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpneBinop_H_
#define _JC_soot_jimple_parser_node_ACmpneBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpne$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpneBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$refs	_jc_soot_jimple_parser_node_ACmpneBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpneBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$object	_jc_soot_jimple_parser_node_ACmpneBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpneBinop$vmethods	_jc_soot_jimple_parser_node_ACmpneBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpneBinop$vtable	_jc_soot_jimple_parser_node_ACmpneBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpneBinop$vtype	_jc_soot_jimple_parser_node_ACmpneBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$_init$8765fe350a00e095(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_TCmpne$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpneBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmpne$object *_jc_soot_jimple_parser_node_ACmpneBinop$method$getCmpne$33d8a622568c22c3(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$setCmpne$02e42f23bba38c57(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_TCmpne$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpneBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$getCmpne$33d8a622568c22c3;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$setCmpne$02e42f23bba38c57;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpneBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmpne$object	*(*getCmpne$33d8a622568c22c3)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmpne$02e42f23bba38c57)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_TCmpne$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpneBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpneBinop$vmethods	soot_jimple_parser_node_ACmpneBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpneBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpneBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpne$object	*__5fcmpne__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpneBinop$refs {
    _jc_soot_jimple_parser_node_ACmpneBinop$sub_refs	soot_jimple_parser_node_ACmpneBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpneBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs	soot_jimple_parser_node_ACmpneBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpneBinop$object {
	_jc_soot_jimple_parser_node_ACmpneBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpneBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpneBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpneBinop$vtype _jc_soot_jimple_parser_node_ACmpneBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpneBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpneBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpneBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpneBinop.h <==
// public final class soot.jimple.parser.node.ACmpneBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 28fea7ff64ce6cdb soot_jimple_parser_node_ACmpneBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpneBinop_H_
#define _JC_soot_jimple_parser_node_ACmpneBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpne$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpneBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$refs	_jc_soot_jimple_parser_node_ACmpneBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpneBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpneBinop$object	_jc_soot_jimple_parser_node_ACmpneBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpneBinop$vmethods	_jc_soot_jimple_parser_node_ACmpneBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpneBinop$vtable	_jc_soot_jimple_parser_node_ACmpneBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpneBinop$vtype	_jc_soot_jimple_parser_node_ACmpneBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$_init$8765fe350a00e095(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_TCmpne$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpneBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmpne$object *_jc_soot_jimple_parser_node_ACmpneBinop$method$getCmpne$33d8a622568c22c3(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpneBinop$method$setCmpne$02e42f23bba38c57(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_TCmpne$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpneBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$getCmpne$33d8a622568c22c3;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$setCmpne$02e42f23bba38c57;
extern _jc_method _jc_soot_jimple_parser_node_ACmpneBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpneBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmpne$object	*(*getCmpne$33d8a622568c22c3)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmpne$02e42f23bba38c57)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *, struct _jc_soot_jimple_parser_node_TCmpne$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpneBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpneBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpneBinop$vmethods	soot_jimple_parser_node_ACmpneBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpneBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpneBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpne$object	*__5fcmpne__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpneBinop$refs {
    _jc_soot_jimple_parser_node_ACmpneBinop$sub_refs	soot_jimple_parser_node_ACmpneBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpneBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpneBinop$sub_nonrefs	soot_jimple_parser_node_ACmpneBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpneBinop$object {
	_jc_soot_jimple_parser_node_ACmpneBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpneBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpneBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpneBinop$vtype _jc_soot_jimple_parser_node_ACmpneBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpneBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpneBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpneBinop_H_ */
